@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
-
 import json
 
 from django.http import HttpResponse
-
+from django.utils.module_loading import import_string
 from taggit.models import Tag
-
-from taggit_selectize.conf import settings
-
+from .conf import settings
 
 def get_tags_recommendation(request):
     """
@@ -16,15 +12,20 @@ def get_tags_recommendation(request):
     Tags are by default limited to 10, use TAGGIT_SELECTIZE_RECOMMENDATION_LIMIT settings to specify.
     """
     query = request.GET.get('query')
+    limit = settings.TAGGIT_SELECTIZE['RECOMMENDATION_LIMIT']
+
+    try:
+        cls = import_string(settings.TAGGIT_SELECTIZE_THROUGH)
+    except AttributeError:
+        cls = Tag
+
     if query:
-        limit = settings.TAGGIT_SELECTIZE_RECOMMENDATION_LIMIT
-        recommended_tags = Tag.objects.filter(name__icontains=query).values('name')[:limit]
-        tags = list(recommended_tags)
+        tags = cls.objects.filter(name__icontains=query).values('name')[:limit]
     else:
-        tags = list(Tag.objects.values()[:10])
+        tags = cls.objects.values()[:limit]
 
     data = json.dumps({
-        'tags': tags
+        'tags': list(tags)
     })
 
-    return HttpResponse(data, content_type='application/json')
\ No newline at end of file
+    return HttpResponse(data, content_type='application/json')
